@@ -39,6 +39,7 @@ val set_verbose : unit -> unit
 val set_silent : unit -> unit
 val set_daemon : unit -> unit
 val set_veryverbose : unit -> unit
+val set_debug : unit -> unit
 val set_minthreads : int -> unit
 val set_maxthreads : int -> unit
 val set_max_number_of_threads_queued : int -> unit
@@ -76,6 +77,7 @@ val get_verbose : unit -> bool
 val get_silent : unit -> bool
 val get_daemon : unit -> bool
 val get_veryverbose : unit -> bool
+val get_debug : unit -> bool
 val get_default_user : unit -> string
 val get_default_group : unit -> string
 val get_minthreads : unit -> int
