@@ -28,7 +28,6 @@ open Ocsigen_lib
 
 open Lwt
 open Ocsigen_extensions
-open Simplexmlparser
 open Ocsigen_http_frame
 open Ocsigen_http_com
 open Ocsigen_senders
@@ -59,7 +58,7 @@ type reg = {
   path: string; (** path of the script *)
   path_info: string; (** path_info environment variable *)
 
-  exec:string option; (** binary to execute the script with (optionnal) *)
+  exec:string option; (** binary to execute the script with (optional) *)
   env:(string * string) list (** environment variables *) }
 
 (*****************************************************************************)
@@ -122,7 +121,7 @@ let string_conform2 s =
 (* split a string in two parts, according to a regexp *)
 let split_regexp r s =
   match Regexp.string_match r s 0 with
-  | None -> None (* the begining of the string doesn't match the regexp *)
+  | None -> None (* the beginning of the string doesn't match the regexp *)
   | Some result ->
     let (split,l) = Regexp.match_end result, String.length s in
     let s' = Regexp.first_chars s split in
@@ -307,7 +306,25 @@ let create_process_cgi filename ri post_out cgi_in err_in re doc_root hostname =
       cgi_in
       err_in
 
-
+(* Copied from deprecated [Lwt_chan]. *)
+let lwt_chan_input_line ic =
+  let rec loop buf =
+    Lwt_io.read_char_opt ic >>= function
+    | None | Some '\n' ->
+      Lwt.return (Buffer.contents buf)
+    | Some char ->
+      Buffer.add_char buf char;
+      loop buf
+  in
+  Lwt_io.read_char_opt ic >>= function
+  | Some '\n' ->
+    Lwt.return ""
+  | Some char ->
+    let buf = Buffer.create 128 in
+    Buffer.add_char buf char;
+    loop buf
+  | None ->
+    Lwt.fail End_of_file
 
 (** This function makes it possible to launch a cgi script *)
 
@@ -368,7 +385,7 @@ let recupere_cgi head re doc_root filename ri hostname =
     Lwt_timeout.start timeout;
 
     (* A thread giving POST data to the CGI script: *)
-    let post_in_ch = Lwt_chan.out_channel_of_descr post_in in
+    let post_in_ch = Lwt_io.of_fd ~mode:Lwt_io.output post_in in
     ignore
       (catch
          (fun () ->
@@ -376,7 +393,7 @@ let recupere_cgi head re doc_root filename ri hostname =
              | None -> Lwt_unix.close post_in
              | Some content_post ->
                Ocsigen_http_com.write_stream post_in_ch content_post >>= fun () ->
-               Lwt_chan.flush post_in_ch >>= fun () ->
+               Lwt_io.flush post_in_ch >>= fun () ->
                Lwt_unix.close post_in
             ))
          (*XXX Check possible errors! *)
@@ -391,9 +408,9 @@ let recupere_cgi head re doc_root filename ri hostname =
 
     (* A thread listening the error output of the CGI script
        and writing them in warnings.log *)
-    let err_channel = Lwt_chan.in_channel_of_descr err_out in
+    let err_channel = Lwt_io.of_fd ~mode:Lwt_io.input err_out in
     let rec get_errors () =
-      Lwt_chan.input_line err_channel >>= fun err ->
+      lwt_chan_input_line err_channel >>= fun err ->
       Lwt_log.ign_warning ~section err;
       get_errors ()
     in ignore
@@ -456,7 +473,7 @@ let get_content str =
 (*****************************************************************************)
 let rec parse_global_config = function
   | [] -> ()
-  | (Element ("cgitimeout", [("value", s)], []))::[] ->
+  | (Xml.Element ("cgitimeout", [("value", s)], []))::[] ->
     cgitimeout := int_of_string s
   | _ -> raise (Error_in_config_file
                   ("Unexpected content inside cgimod config"))
@@ -573,7 +590,7 @@ let gen reg = function
 
 let rec set_env = function
   | [] -> []
-  | (Element("setenv", [("var",vr);("val",vl)], []))::l ->
+  | (Xml.Element("setenv", [("var",vr);("val",vl)], []))::l ->
     if List.mem vr environment
     then (Lwt_log.ign_info_f ~section "Variable no set %s" vr;
           set_env l)
@@ -581,7 +598,7 @@ let rec set_env = function
   | _ :: l -> raise (Error_in_config_file "Bad config tag for <cgi>")
 
 let parse_config _ path _ _ = function
-  | Element ("cgi", atts, l) ->
+  | Xml.Element ("cgi", atts, l) ->
     let good_root r =
       Regexp.quote (string_conform2 r)
     in
