@@ -198,8 +198,8 @@ let _ = Unix.setsid ()
 (** Communication functions: *)
 
 let send outch v =
-  Lwt_chan.output_value outch v >>=
-  (fun () -> Lwt_chan.flush outch)
+  Lwt_io.write_value outch v >>= fun () ->
+  Lwt_io.flush outch
 
 let execute outch =
   let handle_errors f = try f () with e -> send outch (Error e) in
@@ -241,9 +241,9 @@ let execute outch =
 let nb_clients = ref 0
 
 let rec listen_client inch outch =
-  Lwt_chan.input_value inch >>=
-  (fun v -> execute outch v) >>=
-  (fun () -> listen_client inch outch)
+  Lwt_io.read_value inch >>= fun v ->
+  execute outch v >>= fun () ->
+  listen_client inch outch
 
 let finish _ =
   nb_clients := !nb_clients - 1;
@@ -260,8 +260,8 @@ let rec loop socket =
      ignore (
        b := true;
        nb_clients := !nb_clients + 1;
-       let inch = Lwt_chan.in_channel_of_descr indescr in
-       let outch = Lwt_chan.out_channel_of_descr indescr in
+       let inch = Lwt_io.of_fd ~mode:Lwt_io.input indescr in
+       let outch = Lwt_io.of_fd ~mode:Lwt_io.output indescr in
        catch
          (fun () -> listen_client inch outch >>= finish)
          finish);
@@ -272,9 +272,12 @@ let rec loop socket =
 
 let _ = Lwt_main.run
     (let socket = Lwt_unix.socket Unix.PF_UNIX Unix.SOCK_STREAM 0 in
-     (try
-        Lwt_unix.bind socket (Unix.ADDR_UNIX (directory^"/"^socketname))
-      with _ -> errlog ("Please make sure that the directory "^directory^" exists, writable for ocsidbm, and no other ocsidbm process is running on the same directory. If not, remove the file "^(directory^"/"^socketname)); the_end 1);
+     Lwt.catch
+       (fun () ->
+          Lwt_unix.bind socket (Unix.ADDR_UNIX (directory^"/"^socketname)))
+       (fun exn ->
+          errlog ("Please make sure that the directory "^directory^" exists, writable for ocsidbm, and no other ocsidbm process is running on the same directory. If not, remove the file "^(directory^"/"^socketname));
+          the_end 1) >>= fun () ->
      Lwt_unix.listen socket 20;
      (* Done in ocsipersist.ml
         let devnull = Unix.openfile "/dev/null" [Unix.O_WRONLY] 0 in
@@ -341,4 +344,3 @@ let _ = Lwt_main.run
       in ignore (f ())
 
 *)
-
