@@ -34,6 +34,7 @@ val accept_charset : name
 val accept_encoding : name
 val accept_language : name
 val accept_ranges : name
+val authorization : name
 val cache_control : name
 val connection : name
 val content_disposition : name
@@ -54,6 +55,7 @@ val if_unmodified_since : name
 val if_range : name
 val last_modified : name
 val location : name
+val pragma : name
 val server : name
 val set_cookie : name
 val status : name
@@ -110,7 +112,7 @@ val with_defaults : t -> t -> t
 
 
 val dyn_headers : t
-(** Headers for dynamic pages (non cachable) *)
+(** Headers for dynamic pages (non cacheable) *)
 
 type accept =
   ( (string option * string option)
