@@ -18,7 +18,7 @@
 
 (* TODO: rewrite header parsing! *)
 
-(** This module is for getting informations from HTTP header. *)
+(** This module is for getting information from HTTP header. *)
 (** It uses the lowel level module Ocsigen_http_frame.Http_header.    *)
 (** It is very basic and must be completed for exhaustiveness. *)
 (* Operation on strings are hand-written ... *)
@@ -111,8 +111,11 @@ let rec parse_cookies s =
   try
     List.fold_left
       (fun beg a ->
-         let (n, v) = String.sep '=' a in
-         CookiesTable.add n v beg)
+         try
+           let (n, v) = String.sep '=' a in
+           CookiesTable.add n v beg
+         with Not_found ->
+           beg)
       CookiesTable.empty
       splitted
   with _ -> CookiesTable.empty
