@@ -69,7 +69,10 @@ val wait_all_senders : connection -> unit Lwt.t
    interrupted stream exception.
 *)
 val write_stream :
-  ?chunked:bool -> Lwt_chan.out_channel -> string Ocsigen_stream.t -> unit Lwt.t
+  ?chunked:bool ->
+  Lwt_io.output_channel ->
+  string Ocsigen_stream.t ->
+  unit Lwt.t
 
 (****)
 
@@ -104,13 +107,13 @@ val send :
 val abort : connection -> unit
 
 
-(** Use this function to make an action just before sending the result 
+(** Use this function to make an action just before sending the result
     (for example observe the headers that will be sent).
     The parameter is a function taking the set of headers twice,
-    first as [Ocsigen_http_frame.Http_headers.http_header], 
+    first as [Ocsigen_http_frame.Http_headers.http_header],
     second as a [string].
 *)
-val set_result_observer : 
+val set_result_observer :
   (Ocsigen_http_frame.Http_header.http_header -> string -> unit Lwt.t) -> unit
 
 
