@@ -59,7 +59,7 @@ val badconfig : ('a, unit, string, 'b) format4 -> 'a
 (** Type of the result of parsing the field [hostfiler] in the configuration
     file. Inside the list, the first argument is the host itself
     (which is a glob-like pattern that can contains [*]), a regexp
-    parsing this pattern, and optionnaly a port.
+    parsing this pattern, and optionally a port.
 *)
 type virtual_hosts = (string * Netstring_pcre.regexp * int option) list
 
@@ -179,7 +179,7 @@ type answer =
   (** Found but do not try next extensions *)
   | Ext_next of int (** Page not found. Try next extension.
                         The integer is the HTTP error code.
-                        It is usally 404, but may be for ex 403 (forbidden)
+                        It is usually 404, but may be for ex 403 (forbidden)
                         if you want another extension to try after a 403.
                         Same as Ext_continue_with but does not change
                         the request.
@@ -187,20 +187,20 @@ type answer =
   | Ext_stop_site of (Ocsigen_cookies.cookieset * int)
   (** Error. Do not try next extension, but
       try next site.
-      The integer is the HTTP error code, usally 403.
+      The integer is the HTTP error code, usually 403.
   *)
   | Ext_stop_host of (Ocsigen_cookies.cookieset * int)
   (** Error. Do not try next extension,
       do not try next site,
       but try next host.
-      The integer is the HTTP error code, usally 403.
+      The integer is the HTTP error code, usually 403.
   *)
   | Ext_stop_all of (Ocsigen_cookies.cookieset * int)
   (** Error. Do not try next extension (even filters),
       do not try next site,
       do not try next host,
       do not .
-      The integer is the HTTP error code, usally 403.
+      The integer is the HTTP error code, usually 403.
   *)
   | Ext_continue_with of (request * Ocsigen_cookies.cookieset * int)
   (** Used to modify the request before giving it to next extension.
@@ -262,7 +262,7 @@ type extension = request_state -> answer Lwt.t
     the extension may want to modify the result (filters).
 *)
 
-type parse_fun = Simplexmlparser.xml list -> extension2
+type parse_fun = Xml.xml list -> extension2
 
 (** Type of the functions parsing the content of a <host> tag *)
 type parse_host
@@ -305,7 +305,7 @@ and parse_config_user =
   userconf_info -> parse_config
 and parse_config_aux =
     Url.path -> parse_host ->
-    (parse_fun -> Simplexmlparser.xml ->
+    (parse_fun -> Xml.xml ->
      extension
     )
 
@@ -355,7 +355,7 @@ val register_extension :
   ?user_fun_site:parse_config_user ->
   ?begin_init:(unit -> unit) ->
   ?end_init:(unit -> unit) ->
-  ?init_fun:(Simplexmlparser.xml list -> unit) ->
+  ?init_fun:(Xml.xml list -> unit) ->
   ?exn_handler:(exn -> string) ->
   ?respect_pipeline:bool ->
   unit -> unit
@@ -388,7 +388,7 @@ module Configuration : sig
     ?elements:element list ->
     ?attributes:attribute list ->
     ?pcdata:(string -> unit) ->
-    ?other_elements:(string -> (string * string) list -> Simplexmlparser.xml list -> unit) ->
+    ?other_elements:(string -> (string * string) list -> Xml.xml list -> unit) ->
     ?other_attributes:(string -> string -> unit) ->
     unit -> element
 
@@ -416,17 +416,17 @@ module Configuration : sig
     in_tag:string ->
     elements:element list ->
     ?pcdata:(string -> unit) ->
-    ?other_elements:(string -> (string * string) list -> Simplexmlparser.xml list -> unit) ->
-    Simplexmlparser.xml -> unit
+    ?other_elements:(string -> (string * string) list -> Xml.xml list -> unit) ->
+    Xml.xml -> unit
 
   (** Application of [process_element] on a list of XML elements. *)
   val process_elements :
     in_tag:string ->
     elements:element list ->
     ?pcdata:(string -> unit) ->
-    ?other_elements:(string -> (string * string) list -> Simplexmlparser.xml list -> unit) ->
+    ?other_elements:(string -> (string * string) list -> Xml.xml list -> unit) ->
     ?init:(unit -> unit) ->
-    Simplexmlparser.xml list -> unit
+    Xml.xml list -> unit
 
   (** The specification for ignoring blank PCDATA ('\n', '\r', ' ', '\t') and failing
       otherwise (a reasonable default). *)
@@ -524,7 +524,7 @@ val get_numberofreloads : unit -> int
 
 val get_init_exn_handler : unit -> exn -> string
 
-val set_config : Simplexmlparser.xml list -> unit
+val set_config : Xml.xml list -> unit
 
 val client_of_connection : Ocsigen_http_com.connection -> client
 
