@@ -19,7 +19,6 @@
 *)
 
 open Lwt
-open Ocsigen_messages
 open Ocsigen_socket
 open Ocsigen_lib
 open Ocsigen_extensions
@@ -30,7 +29,6 @@ open Ocsigen_senders
 open Ocsigen_config
 open Ocsigen_parseconfig
 open Ocsigen_cookies
-open Lazy
 
 exception Ocsigen_unsupported_media
 exception Ssl_Exception
@@ -49,6 +47,9 @@ let () = Ocsigen_commandline.cmdline
    an exception ... *)
 let _ = Sys.set_signal Sys.sigpipe Sys.Signal_ignore
 
+(* Exit gracefully on SIGINT so that profiling will work *)
+let _ = Sys.set_signal Sys.sigint (Sys.Signal_handle(fun _ -> exit 0))
+
 let section = Lwt_log.Section.make "ocsigen:main"
 
 (* Initialize exception handler for Lwt timeouts: *)
@@ -170,7 +171,7 @@ and find_post_params_multipart_form_data body_gen ctparams filenames
       return ()
     | A_File (_,_,_,wh,_) ->
       let len = String.length s in
-      let r = Unix.write wh s 0 len in
+      let r = Unix.write_substring wh s 0 len in
       if r < len then
         (*XXXX Inefficient if s is long *)
         add where (String.sub s r (len - r))
@@ -1024,16 +1025,19 @@ let errmsg = function
   | (Unix.Unix_error _) as e ->
     (("Fatal - "^(Printexc.to_string e)),
      9)
-  | Ssl.Private_key_error ->
-    (("Fatal - bad password"),
+  | Ssl.Private_key_error msg ->
+    (("Fatal - bad password: " ^ msg),
      10)
   | Ocsigen_config.Config_file_error msg
   | Ocsigen_extensions.Error_in_config_file msg ->
     (("Fatal - Error in configuration file: "^msg),
      50)
-  | Simplexmlparser.Xml_parser_error s ->
-    (("Fatal - Error in configuration file: "^s),
-     51)
+  | Xml.Error (s, loc) ->
+    let begin_char, end_char = Xml.range loc and line = Xml.line loc in
+    raise (Ocsigen_extensions.Error_in_config_file
+             (Printf.sprintf "%s, line %d, characters %d-%d"
+                (Xml.error_msg s)
+                line begin_char end_char))
   | Ocsigen_loader.Dynlink_error (s, exn) ->
     (("Fatal - While loading "^s^": "^(Printexc.to_string exn)),
      52)
@@ -1067,7 +1071,7 @@ let reload_conf s =
 let reload ?file () =
 
   (* That function cannot be interrupted??? *)
-  Lwt_log.ign_warning ~section "Reloading config file" ;
+  Lwt_log.ign_notice ~section "Reloading config file" ;
 
   (try
      match parse_config ?file () with
@@ -1075,7 +1079,7 @@ let reload ?file () =
      | s::_ -> reload_conf s
    with e -> Lwt_log.ign_error ~section (fst (errmsg e)));
 
-  Lwt_log.ign_warning ~section "Config file reloaded"
+  Lwt_log.ign_notice ~section "Config file reloaded"
 
 
 let shutdown_server s l =
@@ -1087,7 +1091,7 @@ let shutdown_server s l =
         Some (float_of_string t)
       | _ -> failwith "syntax error in command"
     in
-    Lwt_log.ign_warning ~section "Shutting down";
+    Lwt_log.ign_notice ~section "Shutting down";
     List.iter
       (fun s -> Lwt_unix.abort s Socket_closed) !sockets;
     List.iter
@@ -1115,14 +1119,14 @@ let _ =
   let f s = function
     | ["reopen_logs"] ->
       Ocsigen_messages.open_files () >>= fun () ->
-      Lwt_log.ign_warning ~section "Log files reopened";
+      Lwt_log.ign_notice ~section "Log files reopened";
       Lwt.return ()
     | ["reload"] -> reload (); Lwt.return ()
     | ["reload"; file] -> reload ~file (); Lwt.return ()
     | "shutdown"::l -> shutdown_server s l; Lwt.return ()
     | ["gc"] ->
       Gc.compact ();
-      Lwt_log.ign_warning ~section "Heap compaction requested by user";
+      Lwt_log.ign_notice ~section "Heap compaction requested by user";
       Lwt.return ()
     | ["clearcache"] -> Ocsigen_cache.clear_all_caches ();
       Lwt.return ()
@@ -1132,27 +1136,50 @@ let _ =
 
 exception Stop of int * string
 
+(* Copied from deprecated [Lwt_chan]. *)
+let lwt_chan_input_line ic =
+  let rec loop buf =
+    Lwt_io.read_char_opt ic >>= function
+    | None | Some '\n' ->
+      Lwt.return (Buffer.contents buf)
+    | Some char ->
+      Buffer.add_char buf char;
+      loop buf
+  in
+  Lwt_io.read_char_opt ic >>= function
+  | Some '\n' ->
+    Lwt.return ""
+  | Some char ->
+    let buf = Buffer.create 128 in
+    Buffer.add_char buf char;
+    loop buf
+  | None ->
+    Lwt.fail End_of_file
+
 let start_server () =
   let stop n fmt = Printf.ksprintf (fun s -> raise (Stop (n, s))) fmt in
   (** Thread waiting for events on a the listening port *)
   let listen use_ssl (addr, port) wait_end_init =
-    let listening_sockets =
-      try
-        let sockets = make_sockets addr port in
-        List.iter (fun x -> Lwt_unix.listen x 1024) sockets;
-        sockets
-      with
-      | Unix.Unix_error (Unix.EACCES, _, _) ->
-        stop 7 "Fatal - You are not allowed to use port %d." port
-      | Unix.Unix_error (Unix.EADDRINUSE, _, _) ->
-        stop 8 "Fatal - The port %d is already in use." port
-      | exn ->
-        stop 100 "Fatal - Uncaught exception: %s" (Printexc.to_string exn)
-    in
-    List.iter (fun x ->
-      ignore (wait_end_init >>= fun () ->
-              wait_connection use_ssl port x)) listening_sockets;
-    listening_sockets
+    Lwt.catch
+      (fun () ->
+         make_sockets addr port >>= fun sockets ->
+         Lwt_list.iter_s
+           (fun x -> Lwt_unix.listen x 1024; Lwt.return ())
+           sockets >>= fun () ->
+         Lwt.return sockets)
+      (function
+        | Unix.Unix_error (Unix.EACCES, _, _) ->
+          stop 7 "Fatal - You are not allowed to use port %d." port
+        | Unix.Unix_error (Unix.EADDRINUSE, _, _) ->
+          stop 8 "Fatal - The port %d is already in use." port
+        | exn ->
+          stop 100 "Fatal - Uncaught exception: %s"
+            (Printexc.to_string exn)) >>= fun listening_sockets ->
+    List.iter
+      (fun x ->
+         ignore (wait_end_init >>= fun () ->
+                 wait_connection use_ssl port x)) listening_sockets;
+    Lwt.return listening_sockets
   in
   try
 
@@ -1190,14 +1217,28 @@ let start_server () =
     in
     let run (user, group) (_, ports, sslports) (minthreads, maxthreads) s =
 
-      Ocsigen_messages.open_files ~user ~group () >>= fun () ->
-
       let wait_end_init, wait_end_init_awakener = wait () in
       (* Listening on all ports: *)
-      sockets := List.fold_left
-          (fun a i -> (listen false i wait_end_init) @ a) [] ports;
-      sslsockets := List.fold_left
-          (fun a i -> (listen true i wait_end_init) @ a) [] sslports;
+
+      let () =
+        Lwt_main.run
+          (Ocsigen_messages.open_files ~user ~group () >>= fun () ->
+
+           Lwt_list.fold_left_s
+             (fun a i ->
+               listen false i wait_end_init >>= fun l ->
+               Lwt.return (l @ a))
+             [] ports >>= fun l ->
+           sockets := l;
+
+           Lwt_list.fold_left_s
+             (fun a i ->
+               listen true i wait_end_init >>= fun l ->
+               Lwt.return (l @ a))
+             [] sslports >>= fun l ->
+           sslsockets := l;
+           Lwt.return_unit)
+      in
 
       begin match ports with
         | (_, p)::_ -> Ocsigen_config.set_default_port p
@@ -1238,7 +1279,7 @@ let start_server () =
             Unix.mkfifo commandpipe 0o660;
             Unix.chown commandpipe uid gid;
             ignore (Unix.umask umask);
-            Lwt_log.ign_warning ~section "Command pipe created";
+            Lwt_log.ign_notice ~section "Command pipe created";
           with e ->
             Lwt_log.ign_error ~section ~exn:e
               "Cannot create the command pipe"));
@@ -1277,7 +1318,6 @@ let start_server () =
                 (fun s -> Lwt_log.ign_error ~section s));
 
       (* Now I can load the modules *)
-      Dynlink_wrapper.init ();
       Dynlink_wrapper.allow_unsafe_modules true;
 
       Ocsigen_extensions.start_initialisation ();
@@ -1306,14 +1346,16 @@ let start_server () =
 
       Ocsigen_extensions.end_initialisation ();
 
-      let pipe = Lwt_chan.in_channel_of_descr
-          (Lwt_unix.of_unix_file_descr
-             (Unix.openfile commandpipe
-                [Unix.O_RDWR; Unix.O_NONBLOCK; Unix.O_APPEND] 0o660)) in
+      let pipe =
+        Lwt_io.of_fd ~mode:Lwt_io.input @@
+        Lwt_unix.of_unix_file_descr @@
+        Unix.openfile commandpipe
+          [Unix.O_RDWR; Unix.O_NONBLOCK; Unix.O_APPEND] 0o660
+      in
 
       let rec f () =
-        Lwt_chan.input_line pipe >>= fun s ->
-        Ocsigen_messages.warning ("Command received: "^s);
+        lwt_chan_input_line pipe >>= fun s ->
+        Lwt_log.ign_notice ~section ("Command received: "^s);
         (Lwt.catch
            (fun () ->
               let prefix, c =
@@ -1344,10 +1386,10 @@ let start_server () =
 
       Lwt.wakeup wait_end_init_awakener ();
 
-      Lwt_log.ign_warning ~section "Ocsigen has been launched \
+      Lwt_log.ign_notice ~section "Ocsigen has been launched \
                                     (initialisations ok)";
 
-      fst (Lwt.wait ())
+      Lwt_main.run @@ fst (Lwt.wait ())
 
     in
 
@@ -1356,16 +1398,51 @@ let start_server () =
       then
         match ssl with
         | None
-        | Some (None, None) -> ()
-        | Some (None, _) -> raise (Ocsigen_config.Config_file_error
-                                     "SSL certificate is missing")
-        | Some (_, None) -> raise (Ocsigen_config.Config_file_error
-                                     "SSL key is missing")
-        | Some ((Some c), (Some k)) ->
+        | Some {ssl_certificate = None; ssl_privatekey = None} -> ()
+        | Some {ssl_certificate = None} ->
+          raise (Ocsigen_config.Config_file_error
+                   "SSL certificate is missing")
+        | Some {ssl_privatekey = None} ->
+          raise (Ocsigen_config.Config_file_error
+                   "SSL key is missing")
+        | Some {ssl_certificate = Some c; ssl_privatekey = Some k} ->
           Ssl.set_password_callback !sslctx (ask_for_passwd sslports);
           Ssl.use_certificate !sslctx c k
     in
 
+    let set_ciphers_if_needed = function
+      | Some {ssl_ciphers = Some s}, _, _ :: _ ->
+        (try
+           Ssl.set_cipher_list !sslctx s
+         with Ssl.Cipher_error ->
+           raise (Ocsigen_config.Config_file_error
+                    "Invalid cipher string"))
+      | _, _, _ ->
+        ()
+    in
+
+    let set_dhfile_if_needed = function
+      | Some {ssl_dhfile = Some e}, _, _ :: _ ->
+        (try
+           Ssl.init_dh_from_file !sslctx e
+         with Ssl.Diffie_hellman_error ->
+           raise (Ocsigen_config.Config_file_error
+                    "Invalid DH file"))
+      | _, _, _ ->
+        ()
+    in
+
+    let set_curve_if_needed = function
+      | Some {ssl_curve = Some c}, _, _ :: _ ->
+        (try
+           Ssl.init_ec_from_named_curve !sslctx c
+         with Ssl.Ec_curve_error ->
+           raise (Ocsigen_config.Config_file_error
+                    "Invalid EC curve"))
+      | _, _, _ ->
+        ()
+    in
+
     let write_pid pid =
       match Ocsigen_config.get_pidfile () with
         None -> ()
@@ -1376,7 +1453,7 @@ let start_server () =
           Unix.openfile
             p
             [Unix.O_WRONLY; Unix.O_CREAT; Unix.O_TRUNC] 0o640 in
-        ignore (Unix.write f spid 0 len);
+        ignore (Unix.write_substring f spid 0 len);
         Unix.close f
     in
 
@@ -1385,12 +1462,15 @@ let start_server () =
       | [h] ->
         let user_info, sslinfo, threadinfo = extract_info h in
         set_passwd_if_needed sslinfo;
+        set_ciphers_if_needed sslinfo;
+        set_dhfile_if_needed sslinfo;
+        set_curve_if_needed sslinfo;
         if (get_daemon ())
         then
           let pid = Lwt_unix.fork () in
           if pid = 0
           then
-            Lwt_main.run (run user_info sslinfo threadinfo h)
+            run user_info sslinfo threadinfo h
           else begin
             Ocsigen_messages.console
               (fun () -> "Process "^(string_of_int pid)^" detached");
@@ -1398,7 +1478,7 @@ let start_server () =
           end
         else begin
           write_pid (Unix.getpid ());
-          Lwt_main.run (run user_info sslinfo threadinfo h)
+          run user_info sslinfo threadinfo h
         end
       | _ -> () (* Multiple servers not supported any more *)
 
